@@ -845,7 +845,6 @@ static void help(TidyDoc tdoc, /**< The tidy document for which help is showing.
     tmbstr temp_string = NULL;
     uint width = 78;
 
-    printf("\n");
     printf( tidyLocalizedString(TC_TXT_HELP_1), get_final_name(prog), tidyLibraryVersion() );
     printf("\n");
 
@@ -1445,6 +1444,24 @@ static void printOptionValues(TidyDoc ARG_UNUSED(tdoc),  /**< The Tidy document.
             }
         }
             break;
+        case TidyPriorityAttributes: /* Is #697 - This case seems missing */
+        {
+            TidyIterator itAttr = tidyOptGetPriorityAttrList(tdoc);
+            if (itAttr && (itAttr != (TidyIterator)-1))
+            {
+                while (itAttr)
+                {
+                    d->def = tidyOptGetNextPriorityAttr(tdoc, &itAttr);
+                    if (itAttr)
+                    {
+                        printf(fmt, d->name, d->type, d->def);
+                        d->name = "";
+                        d->type = "";
+                    }
+                }
+            }
+        }
+            break;
         default:
             break;
     }
@@ -1484,6 +1501,33 @@ static void optionvalues( TidyDoc tdoc )
  ** @{
  */
 
+/* Is #697 - specialised service to 'invert' a buffers content
+   split on a space character */
+static void invertBuffer(TidyBuffer *src, TidyBuffer *dst)
+{
+    uint len = src->size;
+    char *in = (char *)src->bp;
+    char *cp;
+    if (!in)
+        return;
+    while (len)
+    {
+        unsigned char uc;
+        len--;
+        uc = in[len];
+        if (uc == ' ')
+        {
+            in[len] = 0;
+            cp = &in[len + 1];
+            if (dst->size)
+                tidyBufAppend(dst, " ", 1);
+            tidyBufAppend(dst, cp, strlen(cp));
+        }
+    }
+    if (dst->size)
+        tidyBufAppend(dst, " ", 1);
+    tidyBufAppend(dst, in, strlen(in));
+}
 
 /** Prints the option value for a given option.
  */
@@ -1493,6 +1537,7 @@ static void printOptionExportValues(TidyDoc ARG_UNUSED(tdoc),  /**< The Tidy doc
                                     )
 {
     TidyOptionId optId = tidyOptGetId( topt );
+    TidyBuffer buf1, buf2;
 
     if ( tidyOptGetCategory(topt) == TidyInternalCategory )
         return;
@@ -1505,18 +1550,56 @@ static void printOptionExportValues(TidyDoc ARG_UNUSED(tdoc),  /**< The Tidy doc
         case TidyPreTags:
         {
             TidyIterator pos = tidyOptGetDeclTagList( tdoc );
-            while ( pos )
+            if ( pos )  /* Is #697 - one or more values */
             {
-                d->def = tidyOptGetNextDeclTag(tdoc, optId, &pos);
-                if ( pos )
+                tidyBufInit(&buf1);
+                tidyBufInit(&buf2);
+                while (pos)
                 {
-                    printf( "%s: %s\n", d->name, d->def );
-                    d->name = "";
-                    d->type = "";
+                    d->def = tidyOptGetNextDeclTag(tdoc, optId, &pos);
+                    if (d->def)
+                    {
+                        if (buf1.size)
+                            tidyBufAppend(&buf1, " ", 1);
+                        tidyBufAppend(&buf1, (void *)d->def, strlen(d->def));
+                    }
                 }
+                invertBuffer(&buf1, &buf2); /* Is #697 - specialised service to invert words */
+                tidyBufAppend(&buf2, (void *)"\0", 1); /* is this really required? */
+                printf("%s: %s\n", d->name, buf2.bp);
+                d->name = "";
+                d->type = "";
+                d->def = 0;
+                tidyBufFree(&buf1);
+                tidyBufFree(&buf2);
             }
         }
             break;
+        case TidyPriorityAttributes: /* Is #697 - This case seems missing */
+        {
+            TidyIterator itAttr = tidyOptGetPriorityAttrList(tdoc);
+            if (itAttr && (itAttr != (TidyIterator)-1))
+            {
+                tidyBufInit(&buf1);
+                while (itAttr)
+                {
+                    d->def = tidyOptGetNextPriorityAttr(tdoc, &itAttr);
+                    if (d->def)
+                    {
+                        if (buf1.size)
+                            tidyBufAppend(&buf1, " ", 1);
+                        tidyBufAppend(&buf1, (void *)d->def, strlen(d->def));
+                    }
+                }
+                tidyBufAppend(&buf1, (void *)"\0", 1); /* is this really required? */
+                printf("%s: %s\n", d->name, buf1.bp);
+                d->name = "";
+                d->type = "";
+                d->def = 0;
+                tidyBufFree(&buf1);
+            }
+        }
+        break;
         default:
             break;
     }
@@ -1657,6 +1740,10 @@ static void printXMLCrossRefEqConsole(TidyDoc tdoc,   /**< The Tidy document. */
             free((tmbstr)localHit.name3);
             free(localName);
         }
+        if ( localHit.eqconfig ) /* Is. #791 */
+        {
+            free((tmbstr)localHit.eqconfig);
+        }
 
     }
     else
@@ -1803,6 +1890,7 @@ static void xml_help( void )
         if (localPos.name1) free((tmbstr)localPos.name1);
         if (localPos.name2) free((tmbstr)localPos.name2);
         if (localPos.name3) free((tmbstr)localPos.name3);
+        if (localPos.eqconfig) free((tmbstr)localPos.eqconfig); /* Is. #791 */
     }
 
     printf( "</cmdline>\n" );
@@ -2405,8 +2493,17 @@ int main( int argc, char** argv )
         if ( argc > 1 )
         {
             htmlfil = argv[1];
-            DEBUG_LOG( SPRTF("Tidying '%s'\n", htmlfil) );
-            if ( tidyOptGetBool(tdoc, TidyEmacs) )
+#ifdef ENABLE_DEBUG_LOG
+            SPRTF("Tidy: '%s'\n", htmlfil);
+#else /* !ENABLE_DEBUG_LOG */
+            /* Is #713 - show-filename option */
+            if (tidyOptGetBool(tdoc, TidyShowFilename))
+            {
+                fprintf(errout, "Tidy: '%s'", htmlfil);
+                fprintf(errout, "\n");
+            }
+#endif /* ENABLE_DEBUG_LOG yes/no */
+            if ( tidyOptGetBool(tdoc, TidyEmacs) || tidyOptGetBool(tdoc, TidyShowFilename))
                 tidySetEmacsFile( tdoc, htmlfil );
             status = tidyParseFile( tdoc, htmlfil );
         }
